@@ -3,11 +3,14 @@ from getpass import getpass
 
 
 class JaccountCLILogin(JaccountCLIAsyncIO):
-    async def login(self):
+    async def login(self, enable_mask=True):
         await self.init()
         captcha_ascii = self.captcha_generate_ascii()
         print("", captcha_ascii, "", sep="\n")
         captcha = input("Please enter the shown captcha: ")
         username = input("Please enter jaccount username: ")
-        password = getpass("Please enter password: ")
+        if enable_mask:
+            password = getpass("Please enter password: ")
+        else:
+            password = input("Please enter password: ")
         await super().login(username, password, captcha)
